@@ -29,7 +29,7 @@
 
 #include <stdint.h>
 #if defined(__ANDROID__) || defined(AROS) || defined(__PPU__) \
- || ( defined(__APPLE__) && defined(__MACH__) )
+ || ( defined(__APPLE__) && defined(__MACH__) ) || defined(__FreeBSD__) || defined(__OpenBSD__)
 #include <sys/time.h>
 #else
 #include <time.h>
@@ -217,7 +217,6 @@ EXTERN void nfs_destroy_context(struct nfs_context *nfs);
  *                         times before failing and returing an error back
  *                         to the application.
  * version=<3|4>     : NFS version. Default is 3.
- *                     Version 4 is not yet functional. Do not use.
  * nfsport=<port>    : Use this port for NFS instead of using the portmapper.
  * mountport=<port>  : Use this port for the MOUNT protocol instead of
  *                     using portmapper. This argument is ignored for NFSv4
@@ -280,6 +279,7 @@ EXTERN void nfs_set_writemax(struct nfs_context *nfs, uint64_t writemax);
 EXTERN void nfs_set_tcp_syncnt(struct nfs_context *nfs, int v);
 EXTERN void nfs_set_uid(struct nfs_context *nfs, int uid);
 EXTERN void nfs_set_gid(struct nfs_context *nfs, int gid);
+EXTERN void nfs_set_auxiliary_gids(struct nfs_context *nfs, uint32_t len, uint32_t* gids);
 EXTERN void nfs_set_pagecache(struct nfs_context *nfs, uint32_t v);
 EXTERN void nfs_set_pagecache_ttl(struct nfs_context *nfs, uint32_t v);
 EXTERN void nfs_set_readahead(struct nfs_context *nfs, uint32_t v);
